Learn R Programming

dosresmeta (version 1.0)

dosresmeta-package: Performing dose-response meta-analysis

Description

It allows to estimate a dose-response relation from single and multiple summarized data. The trend estimation takes into account the correlation among log relative risks and use it to efficiently estimate the dose-response relation for each study. The results are then combined according to principles of multivariate random effects meta-analysis to obtain a pooled functional relation.

Arguments

Details

ll{ Package: dosresmeta Type: Package Version: 1.0 Date: 2013-08-20 License: GPL-2 }

References

Orsini, N., Bellocco, R., & Greenland, S. (2006). Generalized least squares for trend estimation of summarized dose-response data. Stata Journal, 6(1), 40.

See Also

mvmeta