Approximating covariance matrix according to the method described by Greenland and Longnecker (1992)
Usage
gl(data, epsilon = 0.001)
Arguments
data
the dataset with the information needed to perform the algorithm.
epsilon
define how accurate wuold be the solution for the algorithm
Value
A matrix reporting the pseudo-counts originated from the pubblished data.
Details
No further details required.
References
Greenland, S., Longnecker, M. P. (1992). Methods for trend estimation from summarized dose-response data,
with applications to meta-analysis. American journal of epidemiology, 135(11), 1301-1309.