Learn R Programming

dosresmeta (version 1.0)

hamling: Hamling's method

Description

This function approximates the covariance matrix of log relative risks according to the method described by Hamling (2008).

Usage

hamling(data)

Arguments

data
the dataset with the information needed to perform the algorithm.

Value

  • A matrix reporting the pseudo-counts originated from the pubblished data.

Details

No further details required.

References

Hamling, J., Lee, P., Weitkunat, R., Ambuhl, M. (2008). Facilitating meta-analyses by deriving relative effect and precision estimates for alternative comparisons from a set of estimates presented by exposure level or disease category. Statistics in medicine, 27(7), 954-970.